@@ -1,16 +1,37 @@
 import os, sys, json, random, platform, eventlet, time, re, pyproxify
+#from scapy.all import *
 import itertools
 import threading
 from ua_headers import ua
 eventlet.monkey_patch()
 
+r = "\033[31m"
+g = "\033[32m"
+y = "\033[33m"
+b = "\033[34m"
+p = "\033[35m"
+d = "\033[2;37m"
+w = "\033[0m"
+
+W = f"{w}\033[1;47m"
+R = f"{w}\033[1;41m"
+G = f"{w}\033[1;42m"
+Y = f"{w}\033[1;43m"
+B = f"{w}\033[1;44m"
+space = " "
+
 red = '\033[31m'
 yellow = '\033[93m'
 lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.0"
+version = "1.2.1"
+
+major = str(sys.version_info.major)
+minor = str(sys.version_info.minor)
+path = str(sys.exec_prefix+"/lib/python"+major+"."+minor+"/site-packages/iphack/")
+
 global log
 global anon
 anon = "tor"
@@ -44,7 +65,7 @@ class ip:
             ipdata_list = ['?api-key=6818a70bf0dcdbf1dd6bf89e62299740a49725ac65ff8e4056e3b343', '?api-key=7d9bf69a54c63b6f9274c6074b2f50aee46208d10a33533452add840', '?api-key=6453632fcabd2a4c2de4bb45ab35254594fd719e61d58bacde4429f0']
             ipdata = random.choice(ipdata_list)
             paste = "https://api.ipdata.co/"+ipaddr+ipdata
-            data1 = requests.get(paste, headers=headers, timeout=10).json()
+            data1 = requests.get(paste, headers=headers).json()
             data6 = requests.get("http://ip-api.com/json/"+ipaddr+"?fields=status,message,isp,org,as,reverse,mobile,proxy,hosting,query,district", headers=headers, timeout=10).json()
             data7 = requests.get("https://api.ipregistry.co/"+ipaddr+"?key=g54hjdzjnudhhsp4", headers=headers, timeout=10).json()
             a = lgreen+bold+"["+clear+"+"+lgreen+bold+"]"+clear
@@ -113,7 +134,7 @@ class ip:
             print (red+"[-]"+" Error code: 106 DNS server refused to connect!"+clear)
         except:
             b = red+bold+"["+clear+"-"+red+bold+"]"+clear
-            print(b, "[Error]: Rate limited")
+            print(b, "[-] Unknown Error")
     def my():
         import requests
         headers = {
@@ -174,11 +195,80 @@ class ip:
         a = lgreen+bold+"["+clear+"+"+lgreen+bold+"]"+clear
         r01 = url.replace("https://", "http://")
         url = r01.replace("http://http://", "http://")
+        pr = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+        pr_ip = pr["ip"]
+        pr_port = pr["port"]
+        proxis = pr_ip+":"+pr_port
         res=requests.get(url, stream=True, headers=headers)
         ip=res.raw._original_response.fp.raw._sock.getpeername()[0]
         res2=url + " : " + str(ip)
         print(a, "┌──────────[Domain Ip]")
         print(a, "└ "+url[7:] + " : " + str(ip))
+    def subdomains(*domain:str):
+        import requests
+        print(red+"""
+██╗██████╗░██╗░░██╗░█████╗░░█████╗░██╗░░██╗
+██║██╔══██╗██║░░██║██╔══██╗██╔══██╗██║░██╔╝
+██║██████╔╝███████║███████║██║░░╚═╝█████═╝░
+██║██╔═══╝░██╔══██║██╔══██║██║░░██╗██╔═██╗░
+██║██║░░░░░██║░░██║██║░░██║╚█████╔╝██║░╚██╗
+╚═╝╚═╝░░░░░╚═╝░░╚═╝╚═╝░░╚═╝░╚════╝░╚═╝░░╚═╝"""+red)
+        print(yellow+bold+"        Developer: Misha Korzhik "+clear)
+        print(yellow+bold+"           Tool Version: "+version+" \n"+clear)
+        file = path+"subdomains.txt"
+        domain = " ".join([str(m) for m in domain])
+        subdomains = open(file).read().splitlines()
+        headers={"User-Agent": ua.windows()}
+        sub = True
+        while sub:
+            for subdomain in subdomains:
+                try:
+                    url = f"http://{subdomain}.{domain}"
+                    requests.get(url, headers=headers)
+                except requests.ConnectionError:
+                    pass
+                else:
+                    print(f"{space}{B} DONE {w} Status: {g}valid{w} URL: {url}")
+            sub = False
+    def directory(*domain:str):
+        import requests
+        print(red+"""
+██╗██████╗░██╗░░██╗░█████╗░░█████╗░██╗░░██╗
+██║██╔══██╗██║░░██║██╔══██╗██╔══██╗██║░██╔╝
+██║██████╔╝███████║███████║██║░░╚═╝█████═╝░
+██║██╔═══╝░██╔══██║██╔══██║██║░░██╗██╔═██╗░
+██║██║░░░░░██║░░██║██║░░██║╚█████╔╝██║░╚██╗
+╚═╝╚═╝░░░░░╚═╝░░╚═╝╚═╝░░╚═╝░╚════╝░╚═╝░░╚═╝"""+red)
+        print(yellow+bold+"        Developer: Misha Korzhik "+clear)
+        print(yellow+bold+"           Tool Version: "+version+" \n"+clear)
+        file = path+"directories.txt"
+        domain = " ".join([str(m) for m in domain])
+        directories = open(file).read().splitlines()
+        headers={"User-Agent": ua.windows()}
+        sub = True
+        while sub:
+            for directory in directories:
+                try:
+                    url = f"http://{domain}/{directory}"
+                    code = requests.get(url, headers=headers)
+                    code = code.status_code
+                except requests.ConnectionError:
+                    pass
+                else:
+                    if code == 200:
+                        print(f"{space}{B} DONE {w} Status: {g}valid{w} URL: {url}")
+            sub = False
+    def smtp(email:str, *message:str):
+        import socket, requests
+        server = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
+        mail_ip = str(server["mailip"])
+        mail_port = int(server["mailport"])
+        message = " ".join([str(m) for m in message])
+        client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        client.connect((mail_ip, mail_port))
+        client.sendall(bytes("smtp|"+email+"|"+message,'UTF-8'))
+        code = client.recv(4096)
+        print(code)
     def telegram(data=False):
         import requests
         infinity = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
@@ -393,7 +483,7 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
-                     with eventlet.Timeout(10) as timeoo:
+                     with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
                              get = ss.get(args, **kwargs, headers={"User-Agent": ua.windows()})
@@ -503,7 +593,7 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
-                     with eventlet.Timeout(10) as timeoo:
+                     with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
                              post = ss.post(args, **kwargs, headers={"User-Agent": ua.windows()})
@@ -592,7 +682,7 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
-                     with eventlet.Timeout(10) as timeoo:
+                     with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
                              put = ss.put(args, **kwargs, headers={"User-Agent": ua.windows()})
@@ -681,7 +771,7 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
-                     with eventlet.Timeout(10) as timeoo:
+                     with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
                              delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
@@ -770,7 +860,7 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
-                     with eventlet.Timeout(10) as timeoo:
+                     with eventlet.Timeout(15) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
                              delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
